/***************************************************************************
  DSPCon TPRO/tSAT - Interface Header

		DSPCon, Inc.
		380 FootHill Road
		Bridgewater, NJ 08807
	
		e-mail: info@dspcon.com

  (C) Copyright 2001 DSPCon, Inc.  All rights reserved.
  Use of copyright notice is precautionary and does not imply publication
***************************************************************************/

/***************************************************************************
  TPRO.H
***************************************************************************/

#ifndef _defined_TPRO_
#define _defined_TPRO_

#pragma pack(8)

#ifdef __cplusplus
extern "C" {
#endif


#define DLL_EXPORT  __declspec(dllexport)


/***************************************************************************
			 SUPPORT CONSTANTS
***************************************************************************/


/**
***  Heartbeat constants
**/

#define SIG_PULSE 	(0xE5)		// heartbeat is a pulse
#define SIG_SQUARE	(0xE7)		// heartbeat is a squarewave

#define SIG_NO_JAM	(0)		// start next cycle
#define SIG_JAM		(1)		// start immediately

#define CLK_10MHZ	(0)		// clock frequency for CPCI board
#define CLK_3MHZ	(1)		// clock frequency for CPCI board
#define CLK_1MHZ	(2)		// clock frequency for CPCI board
#define CLK_1KHZ	(3)		// clock frequency for CPCI board


/**
***  Match constants
**/

#define MATCH_TIME_START	(0)		// start time
#define MATCH_TIME_STOP		(1)		// stop time


/**
***  Oscillator frequencies - for Compact PCI Card Only
**/

#define OSC_OUT_OFF		(0)
#define OSC_OUT_1KHZ		(1)
#define OSC_OUT_1MHZ		(2)
#define OSC_OUT_5MHZ		(3)
#define OSC_OUT_10MHZ		(4)


/***************************************************************************
			      OBJECTS
***************************************************************************/

/*==========================================================================
			 TPRO BOARD OBJECT
==========================================================================*/

typedef struct TPRO_BoardObj
{ /*----------------------------------------------------------------------*/
  void *hDevice;

  unsigned short options;
  unsigned char slotPosition;
} /*----------------------------------------------------------------------*/
TPRO_BoardObj;


/*==========================================================================
			TPRO ALTITUDE OBJECT
==========================================================================*/

typedef struct TPRO_AltObj
{ /*----------------------------------------------------------------------*/
  float         meters;				/*-- meters --------------*/
} /*----------------------------------------------------------------------*/
TPRO_AltObj;


/*==========================================================================
			  TPRO DATE OBJECT
==========================================================================*/

typedef struct TPRO_DateObj
{ /*----------------------------------------------------------------------*/
  unsigned short year;				/*-- year ----------------*/
  unsigned char  month;				/*-- month ---------------*/
  unsigned char  day;				/*-- day -----------------*/
} /*----------------------------------------------------------------------*/
TPRO_DateObj;


/*==========================================================================
		  TPRO LONGITUDE/LATTITUDE OBJECT
==========================================================================*/

typedef struct TPRO_LongLat
{ /*----------------------------------------------------------------------*/
  unsigned short degrees;			/*-- degrees -------------*/
  float   	 minutes;			/*-- minutes -------------*/
} /*----------------------------------------------------------------------*/
TPRO_LongObj, TPRO_LatObj;


/*==========================================================================
			 TPRO MATCH OBJECT
==========================================================================*/

typedef struct TPRO_MatchObj
{ /*----------------------------------------------------------------------*/
  unsigned char   matchType;			/*-- start/stop time -----*/

  double 	  seconds;			/*-- seconds -------------*/
  unsigned char   minutes;			/*-- minutes -------------*/
  unsigned char   hours;			/*-- hours ---------------*/
  unsigned short  days;				/*-- days ----------------*/
} /*----------------------------------------------------------------------*/
TPRO_MatchObj;


/*==========================================================================
			TPRO SATINFO OBJECT
==========================================================================*/

typedef struct TPRO_SatObj
{ /*----------------------------------------------------------------------*/
  unsigned char satsTracked;			/*-- num sats tracked ----*/
  unsigned char satsView;			/*-- num sats in view ----*/
} /*----------------------------------------------------------------------*/
TPRO_SatObj;


/*==========================================================================
		       TPRO HEARTBEAT OBJECT
==========================================================================*/

typedef struct TPRO_HeartObj
{ /*----------------------------------------------------------------------*/
  unsigned char signalType;		    	/*-- square or pulse -----*/
  unsigned char outputType;			/*-- jamming option ------*/

  unsigned char clockFreq;			/*-- clock freq for CPCI -*/

  double  frequency;				/*-- heartbeat freq ------*/
} /*----------------------------------------------------------------------*/
TPRO_HeartObj;


/*==========================================================================
			  TPRO TIME OBJECT
==========================================================================*/

typedef struct TPRO_TimeObj
{ /*----------------------------------------------------------------------*/
  double         secsDouble;			/*-- seconds floating pt -*/
  unsigned char  seconds;			/*-- seconds whole num ---*/
  unsigned char  minutes;			/*-- minutes -------------*/
  unsigned char  hours;				/*-- hours ---------------*/
  unsigned short days;				/*-- days ----------------*/

  unsigned short year; 				/*-- year for CPCI board -*/
} /*----------------------------------------------------------------------*/
TPRO_TimeObj;


/*==========================================================================
			  TPRO WAIT OBJECT
==========================================================================*/

typedef struct TPRO_WaitObj
{ /*----------------------------------------------------------------------*/
  unsigned int ticks;				/*-- # ticks to wait -----*/

  double  seconds;				/*-- seconds -------------*/
  unsigned char  minutes;			/*-- minutes -------------*/
  unsigned char  hours;				/*-- hours ---------------*/
  unsigned short days;				/*-- days ----------------*/
} /*----------------------------------------------------------------------*/
TPRO_WaitObj;

/*==========================================================================
		   TPRO MEM OBJECT FOR PEEK/POKE
==========================================================================*/

typedef struct TPRO_MemObj
{ /*----------------------------------------------------------------------*/
  unsigned short offset;
  unsigned short value;

  unsigned long l_value;
} /*----------------------------------------------------------------------*/
TPRO_MemObj;


/***************************************************************************
			    ERROR CODES
***************************************************************************/

#define TPRO_SUCCESS			(0)	// success
#define TPRO_HANDLE_ERR			(1)	// error creating handle to device
#define TPRO_OBJECT_ERR			(2)	// error creating device object
#define TPRO_CLOSE_HANDLE_ERR		(3)	// error closing device handle
#define TPRO_DEVICE_NOT_OPEN_ERR	(4)	// tpro device was not opened
#define TPRO_INVALID_BOARD_TYPE_ERR	(5) 	// function is not available for board type
#define TPRO_FREQ_ERR			(6)	// invalid frequency
#define TPRO_YEAR_PARM_ERR		(7)     // invalid year parameter
#define TPRO_DAY_PARM_ERR		(8)     // invalid day parameter
#define TPRO_HOUR_PARM_ERR		(9)     // invalid hour parameter
#define TPRO_MIN_PARM_ERR	       (10)     // invalid minutes parameter
#define TPRO_SEC_PARM_ERR	       (11)     // invalid seconds parameter
#define TPRO_DELAY_PARM_ERR	       (12)	// invalid delay factor
#define TPRO_TIMEOUT_ERR	       (13)     // device timed out
#define TPRO_COMM_ERR		       (14)	// error communicating with driver


/***************************************************************************
		     PUBLIC ROUTINE PROTOTYPES
***************************************************************************/

DLL_EXPORT
unsigned char TPRO_open             (TPRO_BoardObj **hnd, char *deviceName);

DLL_EXPORT
unsigned char TPRO_close	    (TPRO_BoardObj *hnd);

DLL_EXPORT
unsigned char TPRO_flushFIFO	    (TPRO_BoardObj *hnd);

DLL_EXPORT
unsigned char TPRO_getAltitude      (TPRO_BoardObj *hnd, TPRO_AltObj *Altp);

DLL_EXPORT
unsigned char TPRO_getDate          (TPRO_BoardObj *hnd, TPRO_DateObj *Datep);

DLL_EXPORT
unsigned char TPRO_getDriver	    (TPRO_BoardObj *hnd, char *driver);

DLL_EXPORT
unsigned char TPRO_getFirmware	    (TPRO_BoardObj *hnd, char *firmware);

DLL_EXPORT
unsigned char TPRO_getFPGA	    (TPRO_BoardObj *hnd, char *fpga);

DLL_EXPORT
unsigned char TPRO_getLatitude      (TPRO_BoardObj *hnd, TPRO_LatObj *Latp);

DLL_EXPORT
unsigned char TPRO_getLongitude     (TPRO_BoardObj *hnd, TPRO_LongObj *Longp);

DLL_EXPORT
unsigned char TPRO_getSatInfo       (TPRO_BoardObj *hnd, TPRO_SatObj *Satp);

DLL_EXPORT
unsigned char TPRO_getTime	    (TPRO_BoardObj *hnd, TPRO_TimeObj *Timep);

DLL_EXPORT
unsigned char TPRO_resetFirmware    (TPRO_BoardObj *hnd);

DLL_EXPORT
unsigned char TPRO_setHeartbeat     (TPRO_BoardObj *hnd, TPRO_HeartObj *Heartp);

DLL_EXPORT
unsigned char TPRO_setMatchTime     (TPRO_BoardObj *hnd, TPRO_MatchObj *Matchp);

DLL_EXPORT
unsigned char TPRO_setOscillator    (TPRO_BoardObj *hnd, unsigned char *freq);

DLL_EXPORT
unsigned char TPRO_setPropDelayCorr (TPRO_BoardObj *hnd, int *us);

DLL_EXPORT
unsigned char TPRO_setTime          (TPRO_BoardObj *hnd, TPRO_TimeObj *Timep);

DLL_EXPORT
unsigned char TPRO_setYear          (TPRO_BoardObj *hnd, unsigned short *yr);

DLL_EXPORT
unsigned char TPRO_simEvent	    (TPRO_BoardObj *hnd);

DLL_EXPORT
unsigned char TPRO_synchControl     (TPRO_BoardObj *hnd, unsigned char *enbp);

DLL_EXPORT
unsigned char TPRO_synchStatus      (TPRO_BoardObj *hnd, unsigned char *status);

DLL_EXPORT
unsigned char TPRO_waitEvent        (TPRO_BoardObj *hnd, TPRO_WaitObj *waitp);

DLL_EXPORT
unsigned char TPRO_waitHeartbeat    (TPRO_BoardObj *hnd, unsigned int *ticks);

DLL_EXPORT
unsigned char TPRO_waitMatch        (TPRO_BoardObj *hnd, unsigned int *ticks);

DLL_EXPORT
unsigned char TPRO_peek	    	    (TPRO_BoardObj *hnd, TPRO_MemObj *Mem);

DLL_EXPORT
unsigned char TPRO_poke		    (TPRO_BoardObj *hnd, TPRO_MemObj *Mem);


#ifdef __cplusplus
}
#endif

#pragma pack()

#endif	// _defined_TPRO_
